import * as React from 'react';
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {observer} from "mobx-react-lite";
import {CheckboxField, SelectField, useReadonlyContext} from "@rx-suite/ui";
import { t } from "@lingui/macro";

type Props = {
    component: DashboardComponentModel
}
export const CounterDisplayTypeOptions: React.FunctionComponent<Props> = observer(({ component }) => {
    const readOnly = useReadonlyContext();
    const label = t`Title`;

    if(component.viewModel.display_type !== "counter") {
        return null;
    }

    return <SelectField
        label={label}
        name={"display_options.counter.title"}
        options={[
            { value: "description", label: t`Description` },
            { value: "name", label: t`Name`}
        ]}
        disabled={readOnly}
        onChange={component.handleSelectChange}
        hint={{
            title: label,
            text: t`Select the field to use as the label for the counter. Always falls back to name if no description is present.`
        }}
        value={component.viewModel.display_options?.counter?.title || "description" }
    />
})