import {Typography, Box} from "@material-ui/core";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, SelectField} from "@rx-suite/ui";
import {LabLayoutComponentModel} from "../../stores/LabLayoutComponentStore";
import {t} from "@lingui/macro";

export type MachineStatusDotOptionsFieldsProps = {
    model: LabLayoutComponentModel;
};

export type anchorOption = 'top' | 'right' | 'bottom' | 'left';

export const MachineStatusDotOptionsFields: React.FunctionComponent<MachineStatusDotOptionsFieldsProps> = observer(({model}) => {
    model.ensureOptions();

    const toggleName = React.useCallback(() => {

        if (model.viewModel.options == null) {
            return;
        }

        const oldOptions = JSON.parse(model.viewModel.options);
        const oldShowName = oldOptions.showName;

        oldOptions.showName = (oldShowName == null ? 'top' : null);
        model.viewModel.options = JSON.stringify(oldOptions);

    }, [model, model.viewModel.options]);

    const toggleDuration = React.useCallback(() => {

        if (model.viewModel.options == null) {
            return;
        }

        const oldOptions = JSON.parse(model.viewModel.options);
        const oldShowDuration = oldOptions.showDuration;

        oldOptions.showDuration = (oldShowDuration == null ? 'top' : null);
        model.viewModel.options = JSON.stringify(oldOptions);

    }, [model, model.viewModel.options]);

    const anchorOptions: Array<anchorOption> = ['top', 'right', 'bottom', 'left'];

    const handleNameAnchorChange = React.useCallback((name, value) => {

        if (model.viewModel.options == null) {
            return;
        }

        const oldOptions = JSON.parse(model.viewModel.options);

        oldOptions.showName = value;
        model.viewModel.options = JSON.stringify(oldOptions);

    }, [model, model.viewModel.options]);

    const handleDurationAnchorChange = React.useCallback((name, value) => {
        if (model.viewModel.options == null) {
            return;
        }

        const oldOptions = JSON.parse(model.viewModel.options);

        oldOptions.showDuration = value;
        model.viewModel.options = JSON.stringify(oldOptions);

    }, [model, model.viewModel.options]);

    const optionsJson = JSON.parse(model.viewModel.options as string);

    return <React.Fragment>
        <Box display={'flex'} flexDirection={'column'} alignItems={'flex-start'}>
            <ButtonField
                text={optionsJson.showName ? t`Hide Name` : t`Show Name`}
                variant={optionsJson.showName ? 'outlined' : 'contained'}
                size={'small'}
                onClick={toggleName}
            />
            {optionsJson.showName &&
                <SelectField
                    label={'Name Anchor'}
                    onChange={handleNameAnchorChange}
                    value={optionsJson.showName}
                    options={anchorOptions}
                />
            }
        </Box>
        <Box display={'flex'} flexDirection={'column'} alignItems={'flex-start'}>
            <ButtonField
                text={optionsJson.showDuration ? t`Hide Duration` : t`Show Duration`}
                variant={optionsJson.showDuration ? 'outlined' : 'contained'}
                size={'small'}
                onClick={toggleDuration}
            />
            {optionsJson.showDuration &&
                <SelectField
                    label={'Duration Anchor'}
                    onChange={handleDurationAnchorChange}
                    value={optionsJson.showDuration}
                    options={anchorOptions}
                />
            }
        </Box>
    </React.Fragment>;
});